# CRS robots control at CTU/CIIRC
Package to control CTU/CIIRC robots CRS93 and CRS97 via MARS control unit.

## Installation

```
pip isntall ctu_crs #todo: update with PyPI package
```

## Usage


todo: 
install:
vim
terminator
pycharm
